@@ -342,16 +342,16 @@ typedef struct FAudioDebugConfiguration
 #define FAUDIO_DEFAULT_CHANNELS		0
 #define FAUDIO_DEFAULT_SAMPLERATE	0
 
-#define FAUDIO_DEBUG_ENGINE		0x01
-#define FAUDIO_VOICE_NOPITCH		0x02
-#define FAUDIO_VOICE_NOSRC		0x04
-#define FAUDIO_VOICE_USEFILTER		0x08
-#define FAUDIO_VOICE_MUSIC		0x10
-#define FAUDIO_PLAY_TAILS		0x20
-#define FAUDIO_END_OF_STREAM		0x40
-#define FAUDIO_SEND_USEFILTER		0x80
-
+#define FAUDIO_DEBUG_ENGINE		0x0001
+#define FAUDIO_VOICE_NOPITCH		0x0002
+#define FAUDIO_VOICE_NOSRC		0x0004
+#define FAUDIO_VOICE_USEFILTER		0x0008
+#define FAUDIO_VOICE_MUSIC		0x0010
+#define FAUDIO_PLAY_TAILS		0x0020
+#define FAUDIO_END_OF_STREAM		0x0040
+#define FAUDIO_SEND_USEFILTER		0x0080
 #define FAUDIO_VOICE_NOSAMPLESPLAYED	0x0100
+#define FAUDIO_1024_QUANTUM		0x8000
 
 #define FAUDIO_DEFAULT_FILTER_TYPE	FAudioLowPassFilter
 #define FAUDIO_DEFAULT_FILTER_FREQUENCY	FAUDIO_MAX_FILTER_FREQUENCY
@@ -454,6 +454,7 @@ typedef struct FAudioDebugConfiguration
 #define FAUDIO_FORMAT_IEEE_FLOAT	3
 #define FAUDIO_FORMAT_WMAUDIO2		0x0161
 #define FAUDIO_FORMAT_WMAUDIO3		0x0162
+#define FAUDIO_FORMAT_WMAUDIO_LOSSLESS	0x0163
 #define FAUDIO_FORMAT_XMAUDIO2		0x0166
 #define FAUDIO_FORMAT_EXTENSIBLE	0xFFFE
 
@@ -464,10 +465,10 @@ extern FAudioGUID DATAFORMAT_SUBTYPE_IEEE_FLOAT;
 
 #define FAUDIO_TARGET_VERSION 8 /* Targeting compatibility with XAudio 2.8 */
 
-#define FAUDIO_ABI_VERSION	0
+#define FAUDIO_ABI_VERSION	 0
 #define FAUDIO_MAJOR_VERSION	19
-#define FAUDIO_MINOR_VERSION	07
-#define FAUDIO_PATCH_VERSION	00
+#define FAUDIO_MINOR_VERSION	11
+#define FAUDIO_PATCH_VERSION	 0
 
 #define FAUDIO_COMPILED_VERSION ( \
 	(FAUDIO_ABI_VERSION * 100 * 100 * 100) + \
@@ -715,6 +716,20 @@ FAUDIOAPI void FAudio_SetDebugConfiguration(
 	void* pReserved
 );
 
+/* Requests the values that determine's the engine's update size.
+ * For example, a 48KHz engine with a 1024-sample update period would return
+ * 1024 for the numerator and 48000 for the denominator. With this information,
+ * you can determine the precise update size in milliseconds.
+ *
+ * quantumNumerator - The engine's update size, in sample frames.
+ * quantumDenominator - The engine's sample rate, in Hz
+ */
+FAUDIOAPI void FAudio_GetProcessingQuantum(
+	FAudio *audio,
+	uint32_t *quantumNumerator,
+	uint32_t *quantumDenominator
+);
+
 /* FAudioVoice Interface */
 
 /* Requests basic information about a voice.
